from mediaApiClient.client_stream_controller_v2 import *
from mediaApiClient.client_content_controller_v2 import *
from mediaApiClient.stream_models import *
from mediaApiClient.content_reuest_models import *
from mediaApiClient.content_meta_models import *



from datetime import date

import requests

from mediaApiClient.content_meta_models import ContentMeta, PageWithElements


class ClientContentControllerV2:
    def __init__(self, base_url, auth_token):
        self.base_url = base_url
        self.auth_token = auth_token

    def get_content_by_id(self, content_id):
        url = f"{self.base_url}/api/v2/contents/{content_id}"
        params = {
            "contentId": content_id
        }

        headers = {
            "Authorization-Client": self.auth_token
        }

        content_response = requests.get(url, params=params, headers=headers)

        if content_response.status_code == 200:
            return ContentMeta(**content_response.json())
        else:
            raise Exception(f"Request failed with status code: {content_response.status_code}")

    def get_content_by_filter(self, filter_request, number=0, size=10):
        payload = filter_request.model_dump_json()
        url = f"{self.base_url}/api/v2/contents"

        params = {
            "number": number,
            "size": size
        }

        headers = {
            "Authorization-Client": self.auth_token,
            "Content-Type": "application/json"
        }

        content_response = requests.post(url, data=payload, headers=headers, params=params)

        if content_response.status_code == 200:
            return PageWithElements[ContentMeta](**content_response.json())
        else:
            raise Exception(f"Request failed with status code: {content_response.status_code}")



import requests

from mediaApiClient.stream_models import StreamUrl


class ClientStreamControllerV2:
    def __init__(self, base_url, auth_token):
        self.base_url = base_url
        self.auth_token = auth_token

    def get_stream_for_content(self, content_id, account_id, manifest=None, use_https=None):
        url = f"{self.base_url}/api/v2/stream/contents/{content_id}"
        params = {
            "accountId": account_id
        }

        if manifest is not None:
            params["manifest"] = manifest
        else:
            params["manifest"] = "all"
        if use_https is not None:
            params["useHttps"] = str(use_https).lower()
        else:
            params["useHttps"] = "true"

        headers = {
            "Authorization-Client": self.auth_token
        }

        response = requests.get(url, params=params, headers=headers)

        if response.status_code == 200:
            return StreamUrl(**response.json())
        else:
            raise Exception(f"Request failed with status code: {response.status_code}")



from typing import List, Optional, TypeVar, Generic
from pydantic import BaseModel, Field


class Rating(BaseModel):
    id: Optional[int] = None
    type: Optional[str] = None
    rating: Optional[float] = None


class Genre(BaseModel):
    id: Optional[int] = None
    name: Optional[str] = None


class Country(BaseModel):
    id: Optional[int] = None
    name: Optional[str] = None


class Studio(BaseModel):
    id: Optional[int] = None
    name: Optional[str] = None
    logo: Optional[str] = None


class Poster(BaseModel):
    url: Optional[str] = None
    resizeable: Optional[bool] = None


class ContentMeta(BaseModel):
    id: Optional[str] = None
    title: Optional[str] = None
    originalTitle: Optional[str] = None
    description: Optional[str] = None
    type: Optional[str] = None
    provider: Optional[str] = None
    releaseDate: Optional[int] = None
    ageRating: Optional[int] = None
    slug: Optional[str] = None
    ratingList: Optional[List[Rating]] = None
    genreList: Optional[List[Genre]] = None
    countryList: Optional[List[Country]] = None
    studioList: Optional[List[Studio]] = None
    horizontalPoster: Optional[Poster] = None
    verticalPoster: Optional[Poster] = None


T = TypeVar('T')


class PageWithElements(BaseModel, Generic[T]):
    number: Optional[int] = Field(..., alias="number")
    size: Optional[int] = Field(..., alias="size")
    total_pages: Optional[int] = Field(..., alias="totalPages")
    total_elements: Optional[int] = Field(..., alias="totalElements")
    first: Optional[bool] = Field(..., alias="first")
    last: Optional[bool] = Field(..., alias="last")
    next: Optional[bool] = Field(..., alias="next")
    previous: Optional[bool] = Field(..., alias="previous")
    elements: Optional[List[T]] = Field(..., alias="elements")



from typing import List, Optional
from pydantic import BaseModel


class Language(BaseModel):
    label: Optional[str] = None
    value: Optional[str] = None


class Streams(BaseModel):
    type: Optional[str] = None
    name: Optional[str] = None
    license: Optional[str] = None
    url: Optional[str] = None
    language: Optional[Language] = None


class StreamUrl(BaseModel):
    thumbUrl: Optional[str] = None
    streams: Optional[List[Streams]] = None



from setuptools import setup, find_packages

version = '1.0.0'

with open('README.md', encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='mediaApiClient',
    version=version,
    packages=find_packages(),
    install_requires=[
        'pydantic~=2.2.1',
        'setuptools~=65.5.1',
        'requests~=2.31.0',
    ],
    author='Semyon Shilovskiy',
    author_email='semen.shilovski@yandex.ru',
    description='A library for working with REST API of CAG',
    long_description=long_description,
    long_description_content_type='text/markdown',
    license='Apache License, Version 2.0, see LICENSE file',
    url='https://github.com/semen-shilovski/mediaApiClient',
)



from typing import Optional
from enum import Enum
from datetime import date
from pydantic import BaseModel


class IntervalFilter(Enum):
    ALL = "ALL"
    OTHER = "OTHER"
    TODAY = "TODAY"
    YESTERDAY = "YESTERDAY"
    WEEK = "WEEK"
    MONTH = "MONTH"


class ContentType(Enum):
    FILM = "FILM"
    SERIAL = "SERIAL"
    SHOW = "SHOW"
    ALL = "ALL"


class Service(Enum):
    AMEDIATEKA = "1"
    START = "2"
    PREMIER = "3"
    ALL = "ALL"


class ContentFilter(BaseModel):
    type: str
    intervalFilter: str
    serviceId: str
    dateFrom: Optional[date]
    dateTo: Optional[date]
